--[[
Name: Prat_ArmoryLink
Revision: $Revision: 81743 $
Author(s):  Danny (dekimsey@gmail.com)
Website: http://files.wowace.com/Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#ArmoryLink
Subversion: http://svn.wowace.com/wowace/trunk/Prat/
Discussions: http://groups.google.com/group/wow-prat
Issues and feature requests: http://code.google.com/p/prat/issues/list
Description: Adds a popup winodw that contains a direct url to the WoW Armory page.(default=off).
Dependencies: Prat
]]

-- Get Utility Libraries
local util, DBG, CLR = GetPratUtils()

-- set prat module name
local PRAT_MODULE = Prat:RequestModuleName("ArmoryLink")

-- define localized strings
local L = PRAT_LIBRARY(PRATLIB.LOCALIZATION):new(PRAT_MODULE)

L:RegisterTranslations("enUS", function() return {
	["ArmoryLink"] = true,
	["ArmoryDESC"] = "Adds a popup winodw that contains a direct url to the WoW Armory page.",
    ["WoW Armory link for: %s."] = true
	--[[
		text strings used by the toggleOptions' show{} handler
		NB: other handlers may also generate text needing translations added
	]]
--	["show_name"] = "Show ArmoryLink",		-- example with defaultDB entries below 
--	["show_desc"] = "Toggle Prat_ArmoryLink.",	-- commented out

	--[[
		text strings used by the toggleOptions' show{} handler
		NB: %d replaced with the Frame Name
	]]
--	["show_perframename"] = "Chat%dArmoryLinkMsgsShow",
--	["show_perframedesc"] = "Toggle showing addon messages for chat window %d.",
	} end)

-- get prat module categories
local cat = Prat.Categories

-- create Prat module
Prat_ArmoryLink = Prat:NewModule(PRAT_MODULE, "AceHook-2.1")
Prat_ArmoryLink.revision = tonumber(string.sub("$Revision: 81743 $", 12, -3))

-- define key module values
Prat_ArmoryLink.moduleName	= L["ArmoryLink"]
Prat_ArmoryLink.moduleDesc	= L["ArmoryDESC"]
Prat_ArmoryLink.consoleName	= string.lower(Prat_ArmoryLink.moduleName)
Prat_ArmoryLink.guiName		= Prat_ArmoryLink.moduleName

Prat_ArmoryLink.Categories	= { cat.LINK, cat.INFO }

-- init moduleOoptions (populated by the other various options tables below)
Prat_ArmoryLink.moduleOptions = {}

-- default values for any settings that need them
-- !!
Prat_ArmoryLink.defaultDB = {
	on	= false,
	}


-- any boolean options
Prat_ArmoryLink.toggleOptions = {}

function Prat_ArmoryLink:GetModuleOptions()
	self.moduleOptions = {
		name	= self.moduleName,
		desc	= self.moduleDesc,
		type	= "group",
		args    = nil
	}
	
	return self.moduleOptions
end


--[[------------------------------------------------
    Module Event Functions
------------------------------------------------]]--

-- things to do when the module is enabled
function Prat_ArmoryLink:OnModuleEnable()

    if GetCVar("realmList"):match("^us") then
    -- http://www.armorylite.com/us/%s/%s
        Prat_ArmoryLink.url = "http://us.wowarmory.com/character-sheet.xml?r=%s&n=%s"
    elseif GetCVar("realmList"):match("^eu") then
        Prat_ArmoryLink.url = "http://eu.wowarmory.com/character-sheet.xml?r=%s&n=%s"
    elseif GetCVar("realmList"):match("^ko") then
        Prat_ArmoryLink.url = "http://ko.wowarmory.com/character-sheet.xml?r=%s&n=%s"
    elseif GetCVar("realmList"):match("^tw") then
        Prat_ArmoryLink.url = "http://tw.wowarmory.com/character-sheet.xml?r=%s&n=%s"
    else
        -- how did we get here?
        Prat_ArmoryLink.url = "http://www.wowace.com/forums"
    end
	
	-- hook functions
	-- !!
	self:SecureHook("UnitPopup_ShowMenu")

	-- !!
	-- register slash commands if wanted
	local slashcmds = {
		"/armorylink"
		}

	if slashcmds then
		Prat:RegisterChatCommand(slashcmds, self.moduleOptions, string.upper(self.moduleName))
	end
    
    -- add the bits to the context menus
	UnitPopupButtons['ARMORY_LINK'] = { text = "Armory Link", dist = 0, func = function() Prat_ArmoryLink:UnitPopup_ArmoryLinkOnClick() end , arg1 = "", arg2 = ""}

	tinsert(UnitPopupMenus['PARTY'], #UnitPopupMenus['PARTY']-1, 'ARMORY_LINK')
	tinsert(UnitPopupMenus['FRIEND'], #UnitPopupMenus['FRIEND']-1, 'ARMORY_LINK')
	tinsert(UnitPopupMenus['SELF'], #UnitPopupMenus['SELF']-1, 'ARMORY_LINK')
	tinsert(UnitPopupMenus['PLAYER'], #UnitPopupMenus['PLAYER']-1, 'ARMORY_LINK')
    tinsert(UnitPopupMenus['RAID'], #UnitPopupMenus['RAID']-1, 'ARMORY_LINK')
    tinsert(UnitPopupMenus['RAID_PLAYER'], #UnitPopupMenus['RAID_PLAYER']-1, 'ARMORY_LINK')
    tinsert(UnitPopupMenus['TEAM'], #UnitPopupMenus['TEAM']-1, 'ARMORY_LINK')
end

function Prat_ArmoryLink:UnitPopup_ShowMenu(dropdownMenu, which, unit, name, userData, ...)
	for i=1, UIDROPDOWNMENU_MAXBUTTONS do
		button = getglobal("DropDownList"..UIDROPDOWNMENU_MENU_LEVEL.."Button"..i);

		-- Patch our handler function back in
		if  button.value == "ARMORY_LINK" then
		    button.func = UnitPopupButtons["ARMORY_LINK"].func
		end
	end
end

function Prat_ArmoryLink:UnitPopup_ArmoryLinkOnClick()
	local dropdownFrame = getglobal(UIDROPDOWNMENU_INIT_MENU)
    local name      = dropdownFrame.name
    local server    = dropdownFrame.server
    self:StaticPopupArmoryLink(name,server)
end

-- things to do when the module is disabled
function Prat_ArmoryLink:OnModuleDisable()
	-- unregister events
	self:UnregisterAllEvents()
end

--[[------------------------------------------------
    Core Functions
------------------------------------------------]]--

-- things do stuff here
function Prat_ArmoryLink:getArmoryLink(name,server)
    if name == nil or name == '' then
        return
    end
    if server == nil or server == "" then
        server = GetRealmName()
    end
    return format(Prat_ArmoryLink.url, server, name)
end

	-- define a popup to get the main name
function Prat_ArmoryLink:StaticPopupArmoryLink(name, server)
    StaticPopupDialogs["MENUITEM_ARMORYLINK"] = StaticPopupDialogs["MENUITEM_ARMORYLINK"] or {
        text = L["WoW Armory link for: %s."],
        link = '',
        button2 = ACCEPT,
        hasEditBox = 1,
        hasWideEditBox = 1,

        OnShow = function()
            this:SetWidth(420)

            local editBox = getglobal(this:GetName().."WideEditBox");
            editBox:SetText(StaticPopupDialogs["MENUITEM_ARMORYLINK"].link);
            editBox:SetFocus();
            editBox:HighlightText(0);

            local button = getglobal(this:GetName().."Button2");
            button:ClearAllPoints();
            button:SetWidth(200);
            button:SetPoint("CENTER", editBox, "CENTER", 0, -30);
        end,

        OnHide = function() end,
        OnAccept = function() end,
        OnCancel = function() end,
        EditBoxOnEscapePressed = function() this:GetParent():Hide(); end,
        timeout = 0,
        whileDead = 1,
        hideOnEscape = 1
    };
    local link = self:getArmoryLink(name, server)
    if link == nil then
        link = '<error>'
    end
    StaticPopupDialogs["MENUITEM_ARMORYLINK"].link = link
    StaticPopup_Show ("MENUITEM_ARMORYLINK", name);
end
